@@ -300,7 +300,7 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
 
     def get_mounted_devices(self):
         mountedData = [(x,y) for x,y in self.ZipVars(
-            "os_disk_parent", "os_disk_dev") if isMount(y)]
+            "os_disk_parent", "os_disk_dev") if y and isMount(y)]
         mountedDevices = {}
         for devices, disk  in mountedData:
             if not isMount(disk):
