@@ -2628,8 +2628,12 @@ class VariableOsInstallBtrfsCompression(Variable):
     """
     Алгоритм сжатия для btrfs, в которых выбрано использовать сжатие
     """
-    type = "choice"
+    type = "choiceedit"
     value = "zstd"
 
     def choice(self):
         return ["zlib","lzo","zstd"]
+
+    def check(self, value):
+        if not re.search(r"^(zlib|lzo|zstd|(1[0-9]|1-9))$", value):
+            raise VariableError(_("Wrong btrfs compression"))
